# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeployService.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CasperMessage_pb2 as CasperMessage__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import RhoTypes_pb2 as RhoTypes__pb2
from . import Either_pb2 as Either__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DeployService.proto',
  package='coop.rchain.casper.protocol',
  syntax='proto3',
  serialized_options=_b('\342?!\n\033coop.rchain.casper.protocol\020\001(\001'),
  serialized_pb=_b('\n\x13\x44\x65ployService.proto\x12\x1b\x63oop.rchain.casper.protocol\x1a\x13\x43\x61sperMessage.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x15scalapb/scalapb.proto\x1a\x0eRhoTypes.proto\x1a\x0c\x45ither.proto\"#\n\x0f\x46indDeployQuery\x12\x10\n\x08\x64\x65ployId\x18\x01 \x01(\x0c\"9\n\x16\x46indDeployInBlockQuery\x12\x0c\n\x04user\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"\x1a\n\nBlockQuery\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x1c\n\x0b\x42locksQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\"4\n\x0f\x44\x61taAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x12\n\x04name\x18\x02 \x01(\x0b\x32\x04.Par\"=\n\x17\x43ontinuationAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x13\n\x05names\x18\x02 \x03(\x0b\x32\x04.Par\"(\n\x15\x44\x65ployServiceResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"O\n\x12\x42lockQueryResponse\x12\x39\n\tblockInfo\x18\x01 \x01(\x0b\x32&.coop.rchain.casper.protocol.BlockInfo\"Y\n\x17LightBlockQueryResponse\x12>\n\tblockInfo\x18\x01 \x01(\x0b\x32+.coop.rchain.casper.protocol.LightBlockInfo\"B\n\x11VisualizeDagQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x1e\n\x16showJustificationLines\x18\x02 \x01(\x08\"*\n\x17VisualizeBlocksResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"\x14\n\x12MachineVerifyQuery\"(\n\x15MachineVerifyResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"q\n\x19ListeningNameDataResponse\x12\x44\n\x0c\x62lockResults\x18\x01 \x03(\x0b\x32..coop.rchain.casper.protocol.DataWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"\x82\x01\n!ListeningNameContinuationResponse\x12M\n\x0c\x62lockResults\x18\x01 \x03(\x0b\x32\x37.coop.rchain.casper.protocol.ContinuationsWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"K\n\x17PrivateNamePreviewQuery\x12\x0c\n\x04user\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07nameQty\x18\x03 \x01(\x05\")\n\x1aPrivateNamePreviewResponse\x12\x0b\n\x03ids\x18\x01 \x03(\x0c\"\x19\n\x17LastFinalizedBlockQuery\"W\n\x1aLastFinalizedBlockResponse\x12\x39\n\tblockInfo\x18\x01 \x01(\x0b\x32&.coop.rchain.casper.protocol.BlockInfo\"\xf5\x01\n\x0eLightBlockInfo\x12\x11\n\tblockHash\x18\x01 \x01(\t\x12\x11\n\tblockSize\x18\x02 \x01(\t\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x13\n\x0b\x64\x65ployCount\x18\x05 \x01(\x05\x12\x16\n\x0etupleSpaceHash\x18\x06 \x01(\t\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\x12\x16\n\x0e\x66\x61ultTolerance\x18\x08 \x01(\x02\x12\x16\n\x0emainParentHash\x18\t \x01(\t\x12\x17\n\x0fparentsHashList\x18\n \x03(\t\x12\x0e\n\x06sender\x18\x0b \x01(\t\"\xb1\x02\n\tBlockInfo\x12\x11\n\tblockHash\x18\x01 \x01(\t\x12\x11\n\tblockSize\x18\x02 \x01(\t\x12\x13\n\x0b\x62lockNumber\x18\x03 \x01(\x03\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x13\n\x0b\x64\x65ployCount\x18\x05 \x01(\x05\x12\x16\n\x0etupleSpaceHash\x18\x06 \x01(\t\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\x12\x16\n\x0e\x66\x61ultTolerance\x18\x08 \x01(\x02\x12\x16\n\x0emainParentHash\x18\t \x01(\t\x12\x17\n\x0fparentsHashList\x18\n \x03(\t\x12\x0e\n\x06sender\x18\x0b \x01(\t\x12\x0f\n\x07shardId\x18\x0c \x01(\t\x12\x1a\n\x12\x62ondsValidatorList\x18\r \x03(\t\x12\x12\n\ndeployCost\x18\x0e \x03(\t\"l\n\x11\x44\x61taWithBlockInfo\x12\x1b\n\rpostBlockData\x18\x01 \x03(\x0b\x32\x04.Par\x12:\n\x05\x62lock\x18\x02 \x01(\x0b\x32+.coop.rchain.casper.protocol.LightBlockInfo\"\xae\x01\n\x1a\x43ontinuationsWithBlockInfo\x12T\n\x16postBlockContinuations\x18\x01 \x03(\x0b\x32\x34.coop.rchain.casper.protocol.WaitingContinuationInfo\x12:\n\x05\x62lock\x18\x02 \x01(\x0b\x32+.coop.rchain.casper.protocol.LightBlockInfo\"g\n\x17WaitingContinuationInfo\x12\'\n\x11postBlockPatterns\x18\x01 \x03(\x0b\x32\x0c.BindPattern\x12#\n\x15postBlockContinuation\x18\x02 \x01(\x0b\x32\x04.Par2\xb9\x07\n\rDeployService\x12>\n\x08\x44oDeploy\x12\'.coop.rchain.casper.protocol.DeployData\x1a\x07.Either\"\x00\x12>\n\x08getBlock\x12\'.coop.rchain.casper.protocol.BlockQuery\x1a\x07.Either\"\x00\x12K\n\x0cvisualizeDag\x12..coop.rchain.casper.protocol.VisualizeDagQuery\x1a\x07.Either\"\x00\x30\x01\x12R\n\x14machineVerifiableDag\x12/.coop.rchain.casper.protocol.MachineVerifyQuery\x1a\x07.Either\"\x00\x12\x46\n\rshowMainChain\x12(.coop.rchain.casper.protocol.BlocksQuery\x1a\x07.Either\"\x00\x30\x01\x12\x42\n\tgetBlocks\x12(.coop.rchain.casper.protocol.BlocksQuery\x1a\x07.Either\"\x00\x30\x01\x12N\n\x13listenForDataAtName\x12,.coop.rchain.casper.protocol.DataAtNameQuery\x1a\x07.Either\"\x00\x12^\n\x1blistenForContinuationAtName\x12\x34.coop.rchain.casper.protocol.ContinuationAtNameQuery\x1a\x07.Either\"\x00\x12U\n\x13\x66indBlockWithDeploy\x12\x33.coop.rchain.casper.protocol.FindDeployInBlockQuery\x1a\x07.Either\"\x00\x12\x45\n\nfindDeploy\x12,.coop.rchain.casper.protocol.FindDeployQuery\x1a\x07.Either\"\x00\x12V\n\x13previewPrivateNames\x12\x34.coop.rchain.casper.protocol.PrivateNamePreviewQuery\x1a\x07.Either\"\x00\x12U\n\x12lastFinalizedBlock\x12\x34.coop.rchain.casper.protocol.LastFinalizedBlockQuery\x1a\x07.Either\"\x00\x42$\xe2?!\n\x1b\x63oop.rchain.casper.protocol\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[CasperMessage__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,RhoTypes__pb2.DESCRIPTOR,Either__pb2.DESCRIPTOR,])




_FINDDEPLOYQUERY = _descriptor.Descriptor(
  name='FindDeployQuery',
  full_name='coop.rchain.casper.protocol.FindDeployQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployId', full_name='coop.rchain.casper.protocol.FindDeployQuery.deployId', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=190,
)


_FINDDEPLOYINBLOCKQUERY = _descriptor.Descriptor(
  name='FindDeployInBlockQuery',
  full_name='coop.rchain.casper.protocol.FindDeployInBlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='coop.rchain.casper.protocol.FindDeployInBlockQuery.user', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.FindDeployInBlockQuery.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=249,
)


_BLOCKQUERY = _descriptor.Descriptor(
  name='BlockQuery',
  full_name='coop.rchain.casper.protocol.BlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='coop.rchain.casper.protocol.BlockQuery.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=277,
)


_BLOCKSQUERY = _descriptor.Descriptor(
  name='BlocksQuery',
  full_name='coop.rchain.casper.protocol.BlocksQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.BlocksQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=307,
)


_DATAATNAMEQUERY = _descriptor.Descriptor(
  name='DataAtNameQuery',
  full_name='coop.rchain.casper.protocol.DataAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.DataAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='coop.rchain.casper.protocol.DataAtNameQuery.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=309,
  serialized_end=361,
)


_CONTINUATIONATNAMEQUERY = _descriptor.Descriptor(
  name='ContinuationAtNameQuery',
  full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='coop.rchain.casper.protocol.ContinuationAtNameQuery.names', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=424,
)


_DEPLOYSERVICERESPONSE = _descriptor.Descriptor(
  name='DeployServiceResponse',
  full_name='coop.rchain.casper.protocol.DeployServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='coop.rchain.casper.protocol.DeployServiceResponse.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=466,
)


_BLOCKQUERYRESPONSE = _descriptor.Descriptor(
  name='BlockQueryResponse',
  full_name='coop.rchain.casper.protocol.BlockQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='coop.rchain.casper.protocol.BlockQueryResponse.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=547,
)


_LIGHTBLOCKQUERYRESPONSE = _descriptor.Descriptor(
  name='LightBlockQueryResponse',
  full_name='coop.rchain.casper.protocol.LightBlockQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='coop.rchain.casper.protocol.LightBlockQueryResponse.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=638,
)


_VISUALIZEDAGQUERY = _descriptor.Descriptor(
  name='VisualizeDagQuery',
  full_name='coop.rchain.casper.protocol.VisualizeDagQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='coop.rchain.casper.protocol.VisualizeDagQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showJustificationLines', full_name='coop.rchain.casper.protocol.VisualizeDagQuery.showJustificationLines', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=706,
)


_VISUALIZEBLOCKSRESPONSE = _descriptor.Descriptor(
  name='VisualizeBlocksResponse',
  full_name='coop.rchain.casper.protocol.VisualizeBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='coop.rchain.casper.protocol.VisualizeBlocksResponse.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=750,
)


_MACHINEVERIFYQUERY = _descriptor.Descriptor(
  name='MachineVerifyQuery',
  full_name='coop.rchain.casper.protocol.MachineVerifyQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=772,
)


_MACHINEVERIFYRESPONSE = _descriptor.Descriptor(
  name='MachineVerifyResponse',
  full_name='coop.rchain.casper.protocol.MachineVerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='coop.rchain.casper.protocol.MachineVerifyResponse.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=814,
)


_LISTENINGNAMEDATARESPONSE = _descriptor.Descriptor(
  name='ListeningNameDataResponse',
  full_name='coop.rchain.casper.protocol.ListeningNameDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='coop.rchain.casper.protocol.ListeningNameDataResponse.blockResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='coop.rchain.casper.protocol.ListeningNameDataResponse.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=929,
)


_LISTENINGNAMECONTINUATIONRESPONSE = _descriptor.Descriptor(
  name='ListeningNameContinuationResponse',
  full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse.blockResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='coop.rchain.casper.protocol.ListeningNameContinuationResponse.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1062,
)


_PRIVATENAMEPREVIEWQUERY = _descriptor.Descriptor(
  name='PrivateNamePreviewQuery',
  full_name='coop.rchain.casper.protocol.PrivateNamePreviewQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='coop.rchain.casper.protocol.PrivateNamePreviewQuery.user', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.PrivateNamePreviewQuery.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nameQty', full_name='coop.rchain.casper.protocol.PrivateNamePreviewQuery.nameQty', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1139,
)


_PRIVATENAMEPREVIEWRESPONSE = _descriptor.Descriptor(
  name='PrivateNamePreviewResponse',
  full_name='coop.rchain.casper.protocol.PrivateNamePreviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='coop.rchain.casper.protocol.PrivateNamePreviewResponse.ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1182,
)


_LASTFINALIZEDBLOCKQUERY = _descriptor.Descriptor(
  name='LastFinalizedBlockQuery',
  full_name='coop.rchain.casper.protocol.LastFinalizedBlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1209,
)


_LASTFINALIZEDBLOCKRESPONSE = _descriptor.Descriptor(
  name='LastFinalizedBlockResponse',
  full_name='coop.rchain.casper.protocol.LastFinalizedBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='coop.rchain.casper.protocol.LastFinalizedBlockResponse.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1298,
)


_LIGHTBLOCKINFO = _descriptor.Descriptor(
  name='LightBlockInfo',
  full_name='coop.rchain.casper.protocol.LightBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='coop.rchain.casper.protocol.LightBlockInfo.blockHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='coop.rchain.casper.protocol.LightBlockInfo.blockSize', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='coop.rchain.casper.protocol.LightBlockInfo.blockNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='coop.rchain.casper.protocol.LightBlockInfo.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='coop.rchain.casper.protocol.LightBlockInfo.deployCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tupleSpaceHash', full_name='coop.rchain.casper.protocol.LightBlockInfo.tupleSpaceHash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.LightBlockInfo.timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faultTolerance', full_name='coop.rchain.casper.protocol.LightBlockInfo.faultTolerance', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mainParentHash', full_name='coop.rchain.casper.protocol.LightBlockInfo.mainParentHash', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='coop.rchain.casper.protocol.LightBlockInfo.parentsHashList', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='coop.rchain.casper.protocol.LightBlockInfo.sender', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1301,
  serialized_end=1546,
)


_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='coop.rchain.casper.protocol.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='coop.rchain.casper.protocol.BlockInfo.blockHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='coop.rchain.casper.protocol.BlockInfo.blockSize', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='coop.rchain.casper.protocol.BlockInfo.blockNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='coop.rchain.casper.protocol.BlockInfo.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='coop.rchain.casper.protocol.BlockInfo.deployCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tupleSpaceHash', full_name='coop.rchain.casper.protocol.BlockInfo.tupleSpaceHash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='coop.rchain.casper.protocol.BlockInfo.timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faultTolerance', full_name='coop.rchain.casper.protocol.BlockInfo.faultTolerance', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mainParentHash', full_name='coop.rchain.casper.protocol.BlockInfo.mainParentHash', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='coop.rchain.casper.protocol.BlockInfo.parentsHashList', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='coop.rchain.casper.protocol.BlockInfo.sender', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardId', full_name='coop.rchain.casper.protocol.BlockInfo.shardId', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bondsValidatorList', full_name='coop.rchain.casper.protocol.BlockInfo.bondsValidatorList', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCost', full_name='coop.rchain.casper.protocol.BlockInfo.deployCost', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1549,
  serialized_end=1854,
)


_DATAWITHBLOCKINFO = _descriptor.Descriptor(
  name='DataWithBlockInfo',
  full_name='coop.rchain.casper.protocol.DataWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockData', full_name='coop.rchain.casper.protocol.DataWithBlockInfo.postBlockData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.DataWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=1964,
)


_CONTINUATIONSWITHBLOCKINFO = _descriptor.Descriptor(
  name='ContinuationsWithBlockInfo',
  full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockContinuations', full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo.postBlockContinuations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='coop.rchain.casper.protocol.ContinuationsWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1967,
  serialized_end=2141,
)


_WAITINGCONTINUATIONINFO = _descriptor.Descriptor(
  name='WaitingContinuationInfo',
  full_name='coop.rchain.casper.protocol.WaitingContinuationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockPatterns', full_name='coop.rchain.casper.protocol.WaitingContinuationInfo.postBlockPatterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postBlockContinuation', full_name='coop.rchain.casper.protocol.WaitingContinuationInfo.postBlockContinuation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2246,
)

_DATAATNAMEQUERY.fields_by_name['name'].message_type = RhoTypes__pb2._PAR
_CONTINUATIONATNAMEQUERY.fields_by_name['names'].message_type = RhoTypes__pb2._PAR
_BLOCKQUERYRESPONSE.fields_by_name['blockInfo'].message_type = _BLOCKINFO
_LIGHTBLOCKQUERYRESPONSE.fields_by_name['blockInfo'].message_type = _LIGHTBLOCKINFO
_LISTENINGNAMEDATARESPONSE.fields_by_name['blockResults'].message_type = _DATAWITHBLOCKINFO
_LISTENINGNAMECONTINUATIONRESPONSE.fields_by_name['blockResults'].message_type = _CONTINUATIONSWITHBLOCKINFO
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'].message_type = _BLOCKINFO
_DATAWITHBLOCKINFO.fields_by_name['postBlockData'].message_type = RhoTypes__pb2._PAR
_DATAWITHBLOCKINFO.fields_by_name['block'].message_type = _LIGHTBLOCKINFO
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['postBlockContinuations'].message_type = _WAITINGCONTINUATIONINFO
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['block'].message_type = _LIGHTBLOCKINFO
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockPatterns'].message_type = RhoTypes__pb2._BINDPATTERN
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockContinuation'].message_type = RhoTypes__pb2._PAR
DESCRIPTOR.message_types_by_name['FindDeployQuery'] = _FINDDEPLOYQUERY
DESCRIPTOR.message_types_by_name['FindDeployInBlockQuery'] = _FINDDEPLOYINBLOCKQUERY
DESCRIPTOR.message_types_by_name['BlockQuery'] = _BLOCKQUERY
DESCRIPTOR.message_types_by_name['BlocksQuery'] = _BLOCKSQUERY
DESCRIPTOR.message_types_by_name['DataAtNameQuery'] = _DATAATNAMEQUERY
DESCRIPTOR.message_types_by_name['ContinuationAtNameQuery'] = _CONTINUATIONATNAMEQUERY
DESCRIPTOR.message_types_by_name['DeployServiceResponse'] = _DEPLOYSERVICERESPONSE
DESCRIPTOR.message_types_by_name['BlockQueryResponse'] = _BLOCKQUERYRESPONSE
DESCRIPTOR.message_types_by_name['LightBlockQueryResponse'] = _LIGHTBLOCKQUERYRESPONSE
DESCRIPTOR.message_types_by_name['VisualizeDagQuery'] = _VISUALIZEDAGQUERY
DESCRIPTOR.message_types_by_name['VisualizeBlocksResponse'] = _VISUALIZEBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['MachineVerifyQuery'] = _MACHINEVERIFYQUERY
DESCRIPTOR.message_types_by_name['MachineVerifyResponse'] = _MACHINEVERIFYRESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataResponse'] = _LISTENINGNAMEDATARESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameContinuationResponse'] = _LISTENINGNAMECONTINUATIONRESPONSE
DESCRIPTOR.message_types_by_name['PrivateNamePreviewQuery'] = _PRIVATENAMEPREVIEWQUERY
DESCRIPTOR.message_types_by_name['PrivateNamePreviewResponse'] = _PRIVATENAMEPREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['LastFinalizedBlockQuery'] = _LASTFINALIZEDBLOCKQUERY
DESCRIPTOR.message_types_by_name['LastFinalizedBlockResponse'] = _LASTFINALIZEDBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['LightBlockInfo'] = _LIGHTBLOCKINFO
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['DataWithBlockInfo'] = _DATAWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['ContinuationsWithBlockInfo'] = _CONTINUATIONSWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['WaitingContinuationInfo'] = _WAITINGCONTINUATIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FindDeployQuery = _reflection.GeneratedProtocolMessageType('FindDeployQuery', (_message.Message,), {
  'DESCRIPTOR' : _FINDDEPLOYQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.FindDeployQuery)
  })
_sym_db.RegisterMessage(FindDeployQuery)

FindDeployInBlockQuery = _reflection.GeneratedProtocolMessageType('FindDeployInBlockQuery', (_message.Message,), {
  'DESCRIPTOR' : _FINDDEPLOYINBLOCKQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.FindDeployInBlockQuery)
  })
_sym_db.RegisterMessage(FindDeployInBlockQuery)

BlockQuery = _reflection.GeneratedProtocolMessageType('BlockQuery', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockQuery)
  })
_sym_db.RegisterMessage(BlockQuery)

BlocksQuery = _reflection.GeneratedProtocolMessageType('BlocksQuery', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlocksQuery)
  })
_sym_db.RegisterMessage(BlocksQuery)

DataAtNameQuery = _reflection.GeneratedProtocolMessageType('DataAtNameQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATAATNAMEQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DataAtNameQuery)
  })
_sym_db.RegisterMessage(DataAtNameQuery)

ContinuationAtNameQuery = _reflection.GeneratedProtocolMessageType('ContinuationAtNameQuery', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMEQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ContinuationAtNameQuery)
  })
_sym_db.RegisterMessage(ContinuationAtNameQuery)

DeployServiceResponse = _reflection.GeneratedProtocolMessageType('DeployServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYSERVICERESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DeployServiceResponse)
  })
_sym_db.RegisterMessage(DeployServiceResponse)

BlockQueryResponse = _reflection.GeneratedProtocolMessageType('BlockQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKQUERYRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockQueryResponse)
  })
_sym_db.RegisterMessage(BlockQueryResponse)

LightBlockQueryResponse = _reflection.GeneratedProtocolMessageType('LightBlockQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _LIGHTBLOCKQUERYRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.LightBlockQueryResponse)
  })
_sym_db.RegisterMessage(LightBlockQueryResponse)

VisualizeDagQuery = _reflection.GeneratedProtocolMessageType('VisualizeDagQuery', (_message.Message,), {
  'DESCRIPTOR' : _VISUALIZEDAGQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.VisualizeDagQuery)
  })
_sym_db.RegisterMessage(VisualizeDagQuery)

VisualizeBlocksResponse = _reflection.GeneratedProtocolMessageType('VisualizeBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VISUALIZEBLOCKSRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.VisualizeBlocksResponse)
  })
_sym_db.RegisterMessage(VisualizeBlocksResponse)

MachineVerifyQuery = _reflection.GeneratedProtocolMessageType('MachineVerifyQuery', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEVERIFYQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.MachineVerifyQuery)
  })
_sym_db.RegisterMessage(MachineVerifyQuery)

MachineVerifyResponse = _reflection.GeneratedProtocolMessageType('MachineVerifyResponse', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEVERIFYRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.MachineVerifyResponse)
  })
_sym_db.RegisterMessage(MachineVerifyResponse)

ListeningNameDataResponse = _reflection.GeneratedProtocolMessageType('ListeningNameDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMEDATARESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ListeningNameDataResponse)
  })
_sym_db.RegisterMessage(ListeningNameDataResponse)

ListeningNameContinuationResponse = _reflection.GeneratedProtocolMessageType('ListeningNameContinuationResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMECONTINUATIONRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ListeningNameContinuationResponse)
  })
_sym_db.RegisterMessage(ListeningNameContinuationResponse)

PrivateNamePreviewQuery = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewQuery', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.PrivateNamePreviewQuery)
  })
_sym_db.RegisterMessage(PrivateNamePreviewQuery)

PrivateNamePreviewResponse = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.PrivateNamePreviewResponse)
  })
_sym_db.RegisterMessage(PrivateNamePreviewResponse)

LastFinalizedBlockQuery = _reflection.GeneratedProtocolMessageType('LastFinalizedBlockQuery', (_message.Message,), {
  'DESCRIPTOR' : _LASTFINALIZEDBLOCKQUERY,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.LastFinalizedBlockQuery)
  })
_sym_db.RegisterMessage(LastFinalizedBlockQuery)

LastFinalizedBlockResponse = _reflection.GeneratedProtocolMessageType('LastFinalizedBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _LASTFINALIZEDBLOCKRESPONSE,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.LastFinalizedBlockResponse)
  })
_sym_db.RegisterMessage(LastFinalizedBlockResponse)

LightBlockInfo = _reflection.GeneratedProtocolMessageType('LightBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIGHTBLOCKINFO,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.LightBlockInfo)
  })
_sym_db.RegisterMessage(LightBlockInfo)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINFO,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.BlockInfo)
  })
_sym_db.RegisterMessage(BlockInfo)

DataWithBlockInfo = _reflection.GeneratedProtocolMessageType('DataWithBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAWITHBLOCKINFO,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.DataWithBlockInfo)
  })
_sym_db.RegisterMessage(DataWithBlockInfo)

ContinuationsWithBlockInfo = _reflection.GeneratedProtocolMessageType('ContinuationsWithBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONSWITHBLOCKINFO,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.ContinuationsWithBlockInfo)
  })
_sym_db.RegisterMessage(ContinuationsWithBlockInfo)

WaitingContinuationInfo = _reflection.GeneratedProtocolMessageType('WaitingContinuationInfo', (_message.Message,), {
  'DESCRIPTOR' : _WAITINGCONTINUATIONINFO,
  '__module__' : 'DeployService_pb2'
  # @@protoc_insertion_point(class_scope:coop.rchain.casper.protocol.WaitingContinuationInfo)
  })
_sym_db.RegisterMessage(WaitingContinuationInfo)


DESCRIPTOR._options = None

_DEPLOYSERVICE = _descriptor.ServiceDescriptor(
  name='DeployService',
  full_name='coop.rchain.casper.protocol.DeployService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2249,
  serialized_end=3202,
  methods=[
  _descriptor.MethodDescriptor(
    name='DoDeploy',
    full_name='coop.rchain.casper.protocol.DeployService.DoDeploy',
    index=0,
    containing_service=None,
    input_type=CasperMessage__pb2._DEPLOYDATA,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlock',
    full_name='coop.rchain.casper.protocol.DeployService.getBlock',
    index=1,
    containing_service=None,
    input_type=_BLOCKQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='visualizeDag',
    full_name='coop.rchain.casper.protocol.DeployService.visualizeDag',
    index=2,
    containing_service=None,
    input_type=_VISUALIZEDAGQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='machineVerifiableDag',
    full_name='coop.rchain.casper.protocol.DeployService.machineVerifiableDag',
    index=3,
    containing_service=None,
    input_type=_MACHINEVERIFYQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showMainChain',
    full_name='coop.rchain.casper.protocol.DeployService.showMainChain',
    index=4,
    containing_service=None,
    input_type=_BLOCKSQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlocks',
    full_name='coop.rchain.casper.protocol.DeployService.getBlocks',
    index=5,
    containing_service=None,
    input_type=_BLOCKSQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForDataAtName',
    full_name='coop.rchain.casper.protocol.DeployService.listenForDataAtName',
    index=6,
    containing_service=None,
    input_type=_DATAATNAMEQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForContinuationAtName',
    full_name='coop.rchain.casper.protocol.DeployService.listenForContinuationAtName',
    index=7,
    containing_service=None,
    input_type=_CONTINUATIONATNAMEQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='findBlockWithDeploy',
    full_name='coop.rchain.casper.protocol.DeployService.findBlockWithDeploy',
    index=8,
    containing_service=None,
    input_type=_FINDDEPLOYINBLOCKQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='findDeploy',
    full_name='coop.rchain.casper.protocol.DeployService.findDeploy',
    index=9,
    containing_service=None,
    input_type=_FINDDEPLOYQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='previewPrivateNames',
    full_name='coop.rchain.casper.protocol.DeployService.previewPrivateNames',
    index=10,
    containing_service=None,
    input_type=_PRIVATENAMEPREVIEWQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='lastFinalizedBlock',
    full_name='coop.rchain.casper.protocol.DeployService.lastFinalizedBlock',
    index=11,
    containing_service=None,
    input_type=_LASTFINALIZEDBLOCKQUERY,
    output_type=Either__pb2._EITHER,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEPLOYSERVICE)

DESCRIPTOR.services_by_name['DeployService'] = _DEPLOYSERVICE

# @@protoc_insertion_point(module_scope)
