# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Either.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Either.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\022coop.rchain.either'),
  serialized_pb=_b('\n\x0c\x45ither.proto\x1a\x15scalapb/scalapb.proto\x1a\x19google/protobuf/any.proto\",\n\tEitherAny\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x1f\n\x0b\x45itherError\x12\x10\n\x08messages\x18\x01 \x03(\t\"-\n\rEitherSuccess\x12\x1c\n\x08response\x18\x01 \x01(\x0b\x32\n.EitherAny\"U\n\x06\x45ither\x12\x1d\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.EitherErrorH\x00\x12!\n\x07success\x18\x02 \x01(\x0b\x32\x0e.EitherSuccessH\x00\x42\t\n\x07\x63ontentB\x14\n\x12\x63oop.rchain.eitherb\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_EITHERANY = _descriptor.Descriptor(
  name='EitherAny',
  full_name='EitherAny',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_url', full_name='EitherAny.type_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='EitherAny.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=110,
)


_EITHERERROR = _descriptor.Descriptor(
  name='EitherError',
  full_name='EitherError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='EitherError.messages', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=143,
)


_EITHERSUCCESS = _descriptor.Descriptor(
  name='EitherSuccess',
  full_name='EitherSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='EitherSuccess.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=190,
)


_EITHER = _descriptor.Descriptor(
  name='Either',
  full_name='Either',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='Either.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='Either.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='Either.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=192,
  serialized_end=277,
)

_EITHERSUCCESS.fields_by_name['response'].message_type = _EITHERANY
_EITHER.fields_by_name['error'].message_type = _EITHERERROR
_EITHER.fields_by_name['success'].message_type = _EITHERSUCCESS
_EITHER.oneofs_by_name['content'].fields.append(
  _EITHER.fields_by_name['error'])
_EITHER.fields_by_name['error'].containing_oneof = _EITHER.oneofs_by_name['content']
_EITHER.oneofs_by_name['content'].fields.append(
  _EITHER.fields_by_name['success'])
_EITHER.fields_by_name['success'].containing_oneof = _EITHER.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['EitherAny'] = _EITHERANY
DESCRIPTOR.message_types_by_name['EitherError'] = _EITHERERROR
DESCRIPTOR.message_types_by_name['EitherSuccess'] = _EITHERSUCCESS
DESCRIPTOR.message_types_by_name['Either'] = _EITHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EitherAny = _reflection.GeneratedProtocolMessageType('EitherAny', (_message.Message,), {
  'DESCRIPTOR' : _EITHERANY,
  '__module__' : 'Either_pb2'
  # @@protoc_insertion_point(class_scope:EitherAny)
  })
_sym_db.RegisterMessage(EitherAny)

EitherError = _reflection.GeneratedProtocolMessageType('EitherError', (_message.Message,), {
  'DESCRIPTOR' : _EITHERERROR,
  '__module__' : 'Either_pb2'
  # @@protoc_insertion_point(class_scope:EitherError)
  })
_sym_db.RegisterMessage(EitherError)

EitherSuccess = _reflection.GeneratedProtocolMessageType('EitherSuccess', (_message.Message,), {
  'DESCRIPTOR' : _EITHERSUCCESS,
  '__module__' : 'Either_pb2'
  # @@protoc_insertion_point(class_scope:EitherSuccess)
  })
_sym_db.RegisterMessage(EitherSuccess)

Either = _reflection.GeneratedProtocolMessageType('Either', (_message.Message,), {
  'DESCRIPTOR' : _EITHER,
  '__module__' : 'Either_pb2'
  # @@protoc_insertion_point(class_scope:Either)
  })
_sym_db.RegisterMessage(Either)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
